Summary:	Hierarchical Data Format Library
Name:		HDF
Version:	4.2.8
Release:	%mkrel 3
License:	BSD
Group:		Development/C
URL:		http://www.hdfgroup.org/
Source0:	ftp://ftp.hdfgroup.org/HDF/HDF_Current/src/hdf-%{version}.tar.gz
Patch0:		HDF4.2r4-format_not_a_string_literal_and_no_format_arguments.diff
BuildRequires:	byacc
BuildRequires:	flex
BuildRequires:	gcc-gfortran
BuildRequires:	groff
BuildRequires:	zlib-devel
BuildRequires:	libjpeg-devel
BuildRequires:	netcdf-devel
Provides:	HDF-devel = %{version}-%{release}

%description
HDF is a multi-object file format that facilitates the transfer of various
types of scientific data between machines and operating systems. 
HDF allows self-definitions of data content and easy extensibility for
future enhancements or compatibility with other standard formats.
HDF includes Fortran and C calling interfaces, and utilities to
prepare raw image of data files or for use with other NCSA software.

The HDF library contains interfaces for storing and retrieving compressed or
uncompressed 8-bit and 24=bit raster images with palettes,
n-Dimensional scientific datasets and binary tables. AN interface is also
included that allows arbitrary grouping of other HDF objects.

%package util
Summary:	HDF utilities and test data files
Group:		Graphics/Utilities
Requires:	%{name} = %{version}-%{release}

%description util
This package contains utilities for HDF data manipulation and
test data files.

%prep
%setup -q -n hdf-%{version}
%patch0 -p1 -b .format_not_a_string_literal_and_no_format_arguments

# Make it lib64 aware
find . -name Makefile.in | \
  xargs perl -pi -e "s,^(libdir|LIBDIR)\s+=.+,\1 = \\\$(prefix)/%{_lib},"

%build
export F77=gfortran
export FC=gfortran

# Build with PIC in case static library is built into a DSO afterwards
%ifarch ia64 x86_64
export CFLAGS="%{optflags} -ansi -D_BSD_SOURCE -DPC -DPIC -fPIC"
export CXXFLAGS=$CFLAGS
export FFLAGS="%{optflags}"
%else
export CFLAGS="%{optflags} -ansi -D_BSD_SOURCE -DPC"
export CXXFLAGS=$CFLAGS
export FFLAGS="%{optflags}"
%endif

%configure2_5x --prefix=%{_prefix} \
	--enable-production
%make

mkdir -p samples
cp -a hdf/util/testfiles/* samples

%check
echo ====================TESTING=========================
make CFLAGS="%{optflags} -ansi -D_BSD_SOURCE -DPC" FFLAGS="%{optflags}" \
%ifarch ia64
  check -k || echo make test failed
%else
# (tv) disabled b/c one test failed with 'Arithmetic overflow converting
# INTEGER(4) to INTEGER(1) at (1). This check can be disabled with the option
# -fno-range-check':
  #check
%endif
echo ====================TESTING END=====================



%install
%makeinstall_std
# remove files already provided by other packages (libjpeg, netcdf, zlib)
rm -f %{buildroot}%{_includedir}/{jconfig.h,jerror.h,jmorecfg.h,jpeglib.h} \
    %{buildroot}%{_includedir}/{zconf.h,zlib.h} \
    %{buildroot}%{_bindir}/{ncdump,ncgen} \
    %{buildroot}%{_includedir}/netcdf.{h,inc,f90} \
    %{buildroot}%{_mandir}/man1/ncgen.1 \
    %{buildroot}%{_mandir}/man1/ncdump.1
mv -f %{buildroot}%{_bindir}/vmake %{buildroot}%{_bindir}/vmake-hdf
mkdir -p %{buildroot}%{_datadir}/hdf
cp -aR samples %{buildroot}%{_datadir}/hdf/

# remove unpackaged files
rm -f %{buildroot}%{_prefix}/man/man1/nc{gen,dump}.1*

%files
%doc COPYING README.txt
%{_libdir}/libdf.*a
%{_libdir}/libmfhdf.*a
%{_libdir}/libhdf4.settings
%{_includedir}/*
%{_mandir}/*/*

%files util
%dir %{_datadir}/hdf
%dir %{_datadir}/hdf/samples
%{_bindir}/*
%attr(644,root,root) %{_datadir}/hdf/samples/*


%changelog

* Fri Jan 11 2013 umeabot <umeabot> 4.2.8-3.mga3
+ Revision: 345066
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

  + boklm <boklm>
    - Update group: Graphics/Other -> Graphics/Utilities

* Sun Jan 06 2013 barjac <barjac> 4.2.8-2.mga3
+ Revision: 340077
- updated group
- re-enumerated patch
- fixed unversioned Provides

* Sat Sep 22 2012 grenoya <grenoya> 4.2.8-1.mga3
+ Revision: 296627
-new version 4.2.8

* Sun Nov 06 2011 dmorgan <dmorgan> 4.2.6-2.mga2
+ Revision: 164265
- Add missing sources

* Tue Jul 05 2011 grenoya <grenoya> 4.2.6-1.mga2
+ Revision: 119045
- change back names to HDF, HDF-utils and HDF-devel
- upgrate sources
- remove support for ppc
- remove old patches (0, 1, 2, 3, 4, 5 and 6)
- change rpm names to hdf, hdf-utils and hdf-devel

* Wed Mar 16 2011 grenoya <grenoya> 4.2r4-4.mga1
+ Revision: 72540
- clean old mdv syntax
- imported package HDF

